==> graphql-tools-sequelize-0.9.3.tgz: package/README.md <==

GraphQL-Tools-Sequelize
========================

[HERE BE DRAGONS -- STILL WORK IN PROGRESS]

Resolver Functions for GraphQL-Tools using Sequelize ORM

<p/>
<img src="https://nodei.co/npm/graphql-tools-sequelize.png?downloads=true&stars=true" alt=""/>

<p/>
<img src="https://david-dm.org/rse/graphql-tools-sequelize.png" alt=""/>

About
-----

This Node.js module provides GraphQL resolver functions for [GraphQL
Tools](https://github.com/apollostack/graphql-tools) or plain
[GraphQL.js](https://github.com/graphql/graphql-js) which use the
[Sequelize](http://sequelizejs.com) ORM to access entities and their
relationships in an underlying RDBMS.

Installation
------------

```shell
$ npm install graphql-tools-sequelize
```

Usage
-----

```js
FIXME
```

License
-------

Copyright (c) 2016 Ralf S. Engelschall (http://engelschall.com/)

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> graphql-tools-sequelize-0.9.5.tgz: package/README.md <==

GraphQL-Tools-Sequelize
========================

Resolver Functions for GraphQL-Tools using Sequelize ORM

<p/>
<img src="https://nodei.co/npm/graphql-tools-sequelize.png?downloads=true&stars=true" alt=""/>

<p/>
<img src="https://david-dm.org/rse/graphql-tools-sequelize.png" alt=""/>

About
-----

This Node.js module provides GraphQL resolver functions for [GraphQL
Tools](https://github.com/apollostack/graphql-tools) or plain
[GraphQL.js](https://github.com/graphql/graphql-js) which use the
[Sequelize](http://sequelizejs.com) Object-Relational-Mapper (ORM) to access entities and their
relationships in an underlying RDBMS.

Installation
------------

```shell
$ npm install graphql-tools graphql-tools-sequelize sequelize
```

Usage
-----

Please see the [all-in-one sample](./sample/) for usage details!

Application Programming Interface (API)
---------------------------------------

FIXME

Assumptions
-----------

It is assumed that all your Sequelize entities have a field `id` of type
`UUID` which is the primary key of an entity. It is also assumed that
you define the GraphQL scalar types `UUID` and `JSON` with the help of
[GraphQL-Tools-Types](https://github.com/rse/graphql-tools-types).

License
-------

Copyright (c) 2016 Ralf S. Engelschall (http://engelschall.com/)

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
